@@ -57,7 +57,11 @@
 	'("(V.O.)" . screenplay-voiceover))
   (define-key screenplay-mode-menu-bar-map [bits screenplay-offscreen]
 	'("(O.S.)" . screenplay-offscreen))
-  
+  (define-key screenplay-mode-menu-bar-map [bits screenplay-insert-marker]
+	'("Edit Marker" . screenplay-insert-marker))
+  (define-key screenplay-mode-menu-bar-map [bits screenplay-goto-marker]
+	'("Go to Edit Marker" . screenplay-goto-marker))
+
   (define-key screenplay-mode-menu-bar-map [style]
 	(cons "Style" (make-sparse-keymap "Style")))
   
@@ -119,6 +123,8 @@
   (define-key screenplay-mode-map "\M-0" 'screenplay-continuous)
   (define-key screenplay-mode-map "\M-n" 'screenplay-notes)
   (define-key screenplay-mode-map "\M-p" 'screenplay-count-pages)
+  (define-key screenplay-mode-map "\M-g" 'screenplay-goto-marker)
+  (define-key screenplay-mode-map "\M-m" 'screenplay-insert-marker)
   )
 
 (define-derived-mode screenplay-mode outline-mode "Screenplay"
@@ -420,4 +426,33 @@ Commands:\\{screenplay-mode-map}
   (insert "\n# ")
   )
 
+(defvar screenplay-edit-marker "# [ -- EDIT MARKER -- ]")
+
+(defun screenplay-insert-marker ()
+  "Insert or move edit marker"
+  (interactive)
+  ;; remove last marker
+  (push-mark)
+  (beginning-of-buffer)
+  (if (search-forward screenplay-edit-marker nil t)
+	  (progn
+		(beginning-of-line)
+		(kill-line 1)
+		)
+	)
+  ;; insert new marker
+  (exchange-point-and-mark-nomark)
+  (beginning-of-line)
+  (insert screenplay-edit-marker)
+  (insert "\n")
+  )
+
+(defun screenplay-goto-marker ()
+  "Find edit marker"
+  (interactive)
+  (beginning-of-buffer)
+  (search-forward screenplay-edit-marker)
+  (beginning-of-line)
+  )
+  
 ;; end of screenplay.el  (Th-th-th-that's all folks!)
